#
# spec file for package python-pytest-xprocess
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-xprocess
Version:        1.0.2
Release:        1.1
Summary:        A pytest plugin for managing processes across test runs
License:        MIT
URL:            https://github.com/pytest-dev/pytest-xprocess
Source:         https://files.pythonhosted.org/packages/source/p/pytest-xprocess/pytest-xprocess-%{version}.tar.gz
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest >= 2.8}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-psutil
Requires:       python-pytest >= 2.8
BuildArch:      noarch
%python_subpackages

%description
This will provide a xprocess fixture which can be used to ensure that
external processes on which your application depends are up and running
during testing. You can also use it to start and pre-configure
test-specific databases (i.e. Postgres, Couchdb).

%prep
%setup -q -n pytest-xprocess-%{version}
rm -rvf tests/__pycache__
chmod -x README.rst

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/xprocess
%{python_sitelib}/pytest_xprocess-%{version}*-info

%changelog
* Fri Jun  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * remove tests from source installation
* Mon Apr 15 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Add missing test suite files to source distribution
  * ProcessStarter.pattern is now optional. Users may provide
    either ProcessStarter.pattern or ProcessStarter.callback or
    both.
* Mon Oct  2 2023 Dirk Müller <dmueller@suse.com>
- update to 0.23.0:
  * Drop support for Python 3.7
  * Add support for Python 3.11
  * Remove dependency on `py`
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.22.2:
  * Python 3.10 is now officially supported
  * `surrogateescape` will now be used as error handling strategy
    for encode/decode operations.
  * Make log files persistency, added in `0.21.0`, optional,
    defaulting to True. The previous logging behavior (prior to
    `0.21.0`) can be enabled by setting `persist_logs` flag to
    `False` when calling `XProcess.ensure`.
  * Fix resource warnings due to leaked internal file handles
  * Ignore zombie processes which are erroneously considered
    alive with python 3.11
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Wed Nov 30 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- More specific python_sitelib in %%files
- Update to 0.21.0:
  * Explicitly add py package as a dependency, fixing issue with pytest >=
    7.2.0
  * Process log files will not be overwritten for each new process anymore,
    making it easier to debug issues that occurred in the middle of failed test
    runs
- 0.19.0:
  * drop support for python 3.5 and 3.6
  * reorganize internals. pytest-xprocess is now a package and all resources
    used by running processes are kept as instances of
    :class:XProcessResources.
- 0.18.1:
  * Fix bug with previous release where internal module was missing
- 0.18.0:
  * :method:`ProcessInfo.terminate` will now terminate outer leaves in process
    tree first and work its way towards root process. For example, if a process
    has child and grandchild, xprocess will terminate first child and
    grandchild and only then will the root process receive a termination
    signal.
  * :class:`ProcessStarter` now has attr:terminate_on_interrupt. This flag will
    make xprocess attempt to terminate and clean up all started process
    resources upon interruptions during pytest runs (CTRL+C, SIGINT and
    internal errors) when set to True. It will default to False, so if the
    described behaviour is desired the flag must be explicitly set True.
  * Add a new popen_kwargs variable to ProcessStarter, this variable can be
    used for passing keyword values to the subprocess.Popen constructor, giving
    the user more control over how the process is initialized.
* Sat Jun 19 2021 Michael Ströder <michael@stroeder.com>
- initial packaging of 0.17.1
